=============
Installation
=============

-------------
Requirements
-------------

**The major requirement of cofan is python 3. cofan is a python 3 library and
was never tested in python 2. So first make sure your version of python is 3.**

Furthermore, cofan requires fileslice python library. It will be installed
automatically if you use pip to install cofan.

------------
Installation
------------

Make sure you have pip for python 3 installed.

On windows install using pip by running the
command::
    
    pip install cofan

Or on linux::
    
    pip3 install cofan

Of course, pip command should be in your PATH environment variable. If you are
using windows there is a good chance pip is not in your PATH. In this case you
should specify the full pip path. Search about how to use pip on windows if you
are having trouble.

Try to import cofan to be sure it was installed successfully::

    >>> import cofan
    >>>

If it is imported without errors, you are ready to use it. You may want to have
a look at one or more of the following documents:
    
* :doc:`quick-guide` For those who want short and quick highlights and usage
  example.
* :doc:`serving-a-local-dir` This is the start of the library tutorial. It shows
  different library features.
* :doc:`reference` This is the library reference. All classes and functions
  documentation is here.

